@@ -18,6 +18,7 @@ from .data_exchanger import DataExchanger
 from .helpers import log_conf
 from .helpers.misc import ensure_socket_response, read_or_create_uuid
 from .loop_communication import LoopCommunicator
+from .rest import router
 
 
 class Node(FastAPI):
@@ -41,7 +42,7 @@ class Node(FastAPI):
         self.uuid = uuid or read_or_create_uuid(self.name)
         self.needs_login = needs_login
 
-        self.log = logging.getLogger()
+        self.log = logging.getLogger('Node')
         self.loop_communicator = LoopCommunicator()
         self.websocket_url = self.loop_communicator.websocket_url()
         self.data_exchanger = DataExchanger(None, self.loop_communicator)
@@ -56,6 +57,8 @@ class Node(FastAPI):
 
         self.repeat_task: Any = None
 
+        self.include_router(router)
+
     @property
     def sio_client(self) -> AsyncClient:
         if self._sio_client is None:
